package ru.ulstu.fc.rule.controller;

import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import ru.ulstu.fc.rule.model.Variable;
import ru.ulstu.fc.rule.model.VariableForm;
import ru.ulstu.fc.rule.service.VariableService;

import java.util.List;

@RestController
@RequestMapping("variableRest")
public class VariableRestController {
    private final VariableService variableService;

    public VariableRestController(VariableService variableService) {
        this.variableService = variableService;
    }

    @GetMapping("/list/{projectId}")
    public List<Variable> getList(@PathVariable(value = "projectId") Integer projectId) {
        return variableService.getAllByProject(projectId);
    }

    @GetMapping("/get/{projectId}/{variableId}")
    public Variable getById(@PathVariable(value = "projectId") Integer projectId,
                            @PathVariable(value = "variableId") Integer variableId) {
        return variableService.getById(variableId);
    }

    @PostMapping
    public Variable save(@Valid VariableForm variableForm) {
        return variableService.save(variableForm);
    }

    @DeleteMapping
    public void delete(@Valid VariableForm variableForm) {
        if (variableForm != null && variableForm.getId() != null) {
            variableService.delete(variableForm);
        }
    }
}
